@@ -144,7 +144,7 @@ void ClipPainter::drawPolygon ( const QPolygonF & polygon,
 
         d->clipPolyObject( polygon, clippedPolyObjects, true );
 
-        foreach( const QPolygonF & clippedPolyObject, clippedPolyObjects ) { 
+        for( const QPolygonF & clippedPolyObject: clippedPolyObjects ) { 
             if ( clippedPolyObject.size() > 2 ) {
                 // mDebug() << "Size: " << clippedPolyObject.size();
                 if (d->m_debugPolygonsLevel) {
@@ -196,7 +196,7 @@ void ClipPainter::drawPolyline( const QPolygonF & polygon )
 
         d->clipPolyObject( polygon, clippedPolyObjects, false );
 
-        foreach( const QPolygonF & clippedPolyObject, clippedPolyObjects ) { 
+        for( const QPolygonF & clippedPolyObject: clippedPolyObjects ) { 
             if ( clippedPolyObject.size() > 1 ) {
                 if (d->m_debugPolygonsLevel) {
                     QPen pen = QPainter::pen();
@@ -248,7 +248,7 @@ void ClipPainter::drawPolyline(const QPolygonF & polygon, QVector<QPointF>& labe
 
         d->clipPolyObject( polygon, clippedPolyObjects, false );
 
-        foreach( const QPolygonF & clippedPolyObject, clippedPolyObjects ) { 
+        for( const QPolygonF & clippedPolyObject: clippedPolyObjects ) { 
             if (d->m_debugPolygonsLevel) {
                 QPen pen = QPainter::pen();
                 QPen originalPen = pen;
@@ -316,10 +316,10 @@ void ClipPainter::setPen(const QPen & pen) {
         if (pen != QPainter::pen()) {
             qDebug() << "--" << pen.color()  << QPainter::pen().color() ;
             QPen newPen = pen;
-            newPen.setColor((Qt::GlobalColor)(d->m_debugPenBatchColor));
+            newPen.setColor((Qt::GlobalColor)(d->m_debugPenBatchColor+4));
             QPainter::setPen(newPen);
             d->m_debugPenBatchColor++;
-            d->m_debugPenBatchColor %= 20;
+            d->m_debugPenBatchColor %= 14;
         }
         else {
             qDebug() << "++";
@@ -412,11 +412,8 @@ void ClipPainterPrivate::labelPosition(const QPolygonF & polygon, QVector<QPoint
 bool ClipPainterPrivate::pointAllowsLabel( const QPointF& point )
 {
 
-    if ( point.x() > m_labelAreaMargin && point.x() < q->viewport().width() - m_labelAreaMargin 
-         && point.y() > m_labelAreaMargin && point.y() < q->viewport().height() - m_labelAreaMargin ) {
-        return true;
-    }
-    return false;
+    return point.x() > m_labelAreaMargin && point.x() < q->viewport().width() - m_labelAreaMargin 
+         && point.y() > m_labelAreaMargin && point.y() < q->viewport().height() - m_labelAreaMargin;
 }
 
 QPointF ClipPainterPrivate::interpolateLabelPoint( const QPointF& previousPoint, 
@@ -1300,6 +1297,7 @@ void ClipPainterPrivate::debugDrawNodes( const QPolygonF & polygon )
         if (m_debugPolygonsLevel == 2) {
             q->setFont(QFont(QStringLiteral("Sans Serif"), 7));
             q->setPen("black");
+            q->setBrush(Qt::transparent);
             q->drawText(itPoint->x() + 6.0, itPoint->y() + (15 - (i * 5) % 30) , QString::number(i));
         }
     }
