@@ -11,18 +11,19 @@
 #ifndef MARBLE_DATAMIGRATION_H
 #define MARBLE_DATAMIGRATION_H
 
+#include "marble_export.h"
 #include <QObject>
 
 namespace Marble
 {
 
-class DataMigration : public QObject
+class MARBLE_EXPORT DataMigration : public QObject
 {
     Q_OBJECT
 
  public:
     explicit DataMigration( QObject *parent );
-    virtual ~DataMigration();
+    ~DataMigration() override;
 
  public Q_SLOTS:
     void exec();
