@@ -19,12 +19,12 @@
 #include "ClipPainter.h"
 
 #include <QSizeF>
+
 class QImage;
 class QPaintDevice;
 class QRegion;
 class QString;
 
-
 namespace Marble
 {
 
@@ -93,7 +93,13 @@ class GeoDataPolygon;
 class MARBLE_EXPORT GeoPainter : public ClipPainter
 {
  public:
-     
+    enum Frame {
+        NoOptions = 0x0,
+        RoundFrame = 0x1
+    };
+
+    Q_DECLARE_FLAGS(Frames, Frame)
+
 /*!
     \brief Creates a new geo painter.
 
@@ -425,6 +431,9 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
     void drawPolygon ( const GeoDataPolygon & polygon,
                        Qt::FillRule fillRule = Qt::OddEvenFill );
 
+
+    QVector<QPolygonF*> createFillPolygons( const QVector<QPolygonF*> & outerPolygons,
+                                            const QVector<QPolygonF*> & innerPolygons ) const;
     
 /*!
     \brief Draws a rectangle at the given position.
@@ -495,6 +504,10 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
                          qreal xRnd = 25.0, qreal yRnd = 25.0);
 
 
+    void drawTextFragment(const QPoint &position, const QString &text,
+                          const qreal fontSize, const QColor &color = Qt::black,
+                          const Frames &flags = 0);
+
 
     // Reenabling QPainter+ClipPainter methods.
     using QPainter::drawText;
