@@ -22,6 +22,7 @@
 // Qt
 #include <QTime>
 #include <QRegion>
+#include <QtMath>
 
 // Marble
 #include "layers/FloatItemsLayer.h"
@@ -209,9 +210,6 @@ MarbleMapPrivate::MarbleMapPrivate( MarbleMap *parent, MarbleModel *model ) :
 
     QObject::connect( &m_geometryLayer, SIGNAL(repaintNeeded()),
                       parent, SIGNAL(repaintNeeded()));
-    QObject::connect(&m_vectorTileLayer, SIGNAL(tileLevelChanged(int)), &m_geometryLayer, SLOT(setTileLevel(int)));
-    QObject::connect(&m_vectorTileLayer, SIGNAL(tileLevelChanged(int)), &m_placemarkLayer, SLOT(setTileLevel(int)));
-    QObject::connect(&m_textureLayer, SIGNAL(tileLevelChanged(int)), &m_placemarkLayer, SLOT(setTileLevel(int)));
 
     /*
      * Slot handleHighlight finds all placemarks
@@ -238,9 +236,11 @@ MarbleMapPrivate::MarbleMapPrivate( MarbleMap *parent, MarbleModel *model ) :
                       parent, SLOT(updateTileLevel()) );
     QObject::connect( &m_vectorTileLayer, SIGNAL(tileLevelChanged(int)),
                       parent, SLOT(updateTileLevel()) );
+    QObject::connect( parent, SIGNAL(radiusChanged(int)),
+                      parent, SLOT(updateTileLevel()) );
+
     QObject::connect( &m_textureLayer, SIGNAL(repaintNeeded()),
                       parent, SIGNAL(repaintNeeded()) );
-
     QObject::connect( parent, SIGNAL(visibleLatLonAltBoxChanged(GeoDataLatLonAltBox)),
                       parent, SIGNAL(repaintNeeded()) );
 
@@ -465,7 +465,8 @@ int MarbleMap::preferredRadiusFloor( int radius )
 
 int MarbleMap::tileZoomLevel() const
 {
-    return qMax(d->m_textureLayer.tileZoomLevel(), d->m_vectorTileLayer.tileZoomLevel());
+    auto const tileZoomLevel = qMax(d->m_textureLayer.tileZoomLevel(), d->m_vectorTileLayer.tileZoomLevel());
+    return tileZoomLevel >= 0 ? tileZoomLevel : qMin<int>(qMax<int>(qLn(d->m_viewport.radius()*4/256)/qLn(2.0), 1), d->m_styleBuilder.maximumZoomLevel());
 }
 
 
@@ -827,7 +828,10 @@ void MarbleMapPrivate::setDocument( const QString& key )
 
 void MarbleMapPrivate::updateTileLevel()
 {
-    emit q->tileLevelChanged(q->tileZoomLevel());
+    auto const tileZoomLevel = q->tileZoomLevel();
+    m_geometryLayer.setTileLevel(tileZoomLevel);
+    m_placemarkLayer.setTileLevel(tileZoomLevel);
+    emit q->tileLevelChanged(tileZoomLevel);
 }
 
 // Used to be paintEvent()
@@ -1444,6 +1448,19 @@ const StyleBuilder* MarbleMap::styleBuilder() const
     return &d->m_styleBuilder;
 }
 
+qreal MarbleMap::heading() const
+{
+    return d->m_viewport.heading() * RAD2DEG;
+}
+
+void MarbleMap::setHeading( qreal heading )
+{
+    d->m_viewport.setHeading( heading * DEG2RAD );
+    d->m_textureLayer.setNeedsUpdate();
+
+    emit visibleLatLonAltBoxChanged( d->m_viewport.viewLatLonAltBox() );
+}
+
 }
 
 #include "moc_MarbleMap.cpp"
