@@ -574,7 +574,7 @@ void MarbleZipReaderPrivate::scanFiles()
         l = readUShort(header.h.file_comment_length);
         header.file_comment = device->read(l);
         if (header.file_comment.length() != l) {
-            qWarning() << "QZip: Failed to read read file comment, index may be incomplete";
+            qWarning() << "QZip: Failed to read file comment, index may be incomplete";
             break;
         }
 
@@ -938,7 +938,7 @@ bool MarbleZipReader::extractAll(const QString &destinationDir) const
 
     // create directories first
     QList<FileInfo> allFiles = fileInfoList();
-    foreach (const FileInfo& fi, allFiles) {
+    for (const FileInfo& fi: allFiles) {
         const QString absPath = destinationDir + QDir::separator() + fi.filePath;
         if (fi.isDir) {
             if (!baseDir.mkpath(fi.filePath))
@@ -949,7 +949,7 @@ bool MarbleZipReader::extractAll(const QString &destinationDir) const
     }
 
     // set up symlinks
-    foreach (const FileInfo& fi, allFiles) {
+    for (const FileInfo& fi: allFiles) {
         const QString absPath = destinationDir + QDir::separator() + fi.filePath;
         if (fi.isSymLink) {
             QString destination = QFile::decodeName(fileData(fi.filePath));
@@ -967,7 +967,7 @@ bool MarbleZipReader::extractAll(const QString &destinationDir) const
         }
     }
 
-    foreach (const FileInfo& fi, allFiles) {
+    for (const FileInfo& fi: allFiles) {
         const QString absPath = destinationDir + QDir::separator() + fi.filePath;
         if (fi.isFile) {
             QDir::root().mkpath(QFileInfo(absPath).dir().absolutePath());
