@@ -29,8 +29,8 @@ class SunLightBlending: public Blending
 {
  public:
     explicit SunLightBlending( const SunLocator * sunLocator );
-    virtual ~SunLightBlending();
-    virtual void blend( QImage * const bottom, TextureTile const * const top ) const;
+    ~SunLightBlending() override;
+    void blend( QImage * const bottom, TextureTile const * const top ) const override;
 
     void setLevelZeroLayout( int levelZeroColumns, int levelZeroRows );
 
