@@ -40,12 +40,13 @@ public:
     };
 
     explicit CloudRouteModel( QObject *parent = 0 );
+    ~CloudRouteModel() override;
 
-    QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
-    int rowCount( const QModelIndex& parent = QModelIndex() ) const;
+    QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const override;
+    int rowCount( const QModelIndex& parent = QModelIndex() ) const override;
 
     /** Overload of QAbstractListModel */
-    QHash<int, QByteArray> roleNames() const;
+    QHash<int, QByteArray> roleNames() const override;
 
     /**
      * Sets the list of routes that will show up in CloudRoutesDialog.
