@@ -30,7 +30,6 @@
 #include "AbstractFloatItem.h"
 #include "RenderPlugin.h"
 #include "MarblePlacemarkModel.h"
-#include "DeclarativeDataPlugin.h"
 #include "SearchBackend.h"
 #include "MarbleQuickItem.h"
 
@@ -58,7 +57,6 @@ void MarbleDeclarativePlugin::registerTypes( const char *uri )
     qmlRegisterType<Marble::NewstuffModel>( uri, 0, 20, "NewstuffModel" );
     qmlRegisterType<OfflineDataModel>( uri, 0, 20, "OfflineDataModel" );
     qmlRegisterType<MapThemeModel>( uri, 0, 20, "MapThemeModel" );
-    qmlRegisterType<DeclarativeDataPlugin>( uri, 0, 20, "DataLayer" );
 
     qmlRegisterType<Marble::SearchBackend>(uri, 0, 20, "SearchBackend");
     qRegisterMetaType<Marble::MarblePlacemarkModel*>("MarblePlacemarkModel*");
@@ -68,6 +66,8 @@ void MarbleDeclarativePlugin::registerTypes( const char *uri )
                                                              QStringLiteral("MarblePlacemarkModel is not instantiable"));
     qmlRegisterUncreatableType<Marble::RoutingModel>(uri, 0, 20, "RoutingModel",
                                                      QStringLiteral("RoutingModel is not instantiable"));
+    qmlRegisterUncreatableType<Marble::RouteRelationModel>(uri, 0, 20, "RouteRelationModel",
+                                                           QStringLiteral("RouteRelationModel is not instantiable"));
     qmlRegisterUncreatableType<Marble::BookmarksModel>(uri, 0, 20, "BookmarksModel",
                                                        QStringLiteral("Do not create"));
     qmlRegisterUncreatableType<Marble::AbstractFloatItem>(uri, 0, 20, "FloatItem",
