@@ -32,12 +32,14 @@
 #include <MarbleMath.h>
 #include <GeoDataLatLonAltBox.h>
 #include <GeoDataCoordinates.h>
-#include <GeoDataTypes.h>
 #include <ReverseGeocodingRunnerManager.h>
 #include <routing/RoutingManager.h>
 #include <routing/RoutingModel.h>
 #include <routing/Route.h>
 #include <BookmarkManager.h>
+#include "GeoDataRelation.h"
+#include "osm/OsmPlacemarkData.h"
+#include "GeoDataDocument.h"
 
 namespace Marble
 {
@@ -45,11 +47,12 @@ namespace Marble
     class QuickItemSelectionRubber : public AbstractSelectionRubber
     { //TODO: support rubber selection in MarbleQuickItem
     public:
-        void show() { m_visible = true; }
-        void hide() { m_visible = false; }
-        bool isVisible() const { return m_visible; }
-        const QRect &geometry() const { return m_geometry; }
-        void setGeometry(const QRect &/*geometry*/) {}
+        QuickItemSelectionRubber();
+        void show() override { m_visible = true; }
+        void hide() override { m_visible = false; }
+        bool isVisible() const override { return m_visible; }
+        const QRect &geometry() const override { return m_geometry; }
+        void setGeometry(const QRect &/*geometry*/) override {}
     private:
         QRect m_geometry;
         bool m_visible;
@@ -66,7 +69,7 @@ namespace Marble
             setInertialEarthRotationEnabled(false); //Disabled by default, it's buggy. TODO - fix
         }
 
-        bool acceptMouse()
+        bool acceptMouse() override
         {
             return true;
         }
@@ -76,37 +79,37 @@ namespace Marble
             (void)handlePinch(center, scale, state);
         }
 
-        void handleMouseButtonPressAndHold(const QPoint &position)
+        void handleMouseButtonPressAndHold(const QPoint &position) override
         {
             m_marbleQuick->reverseGeocoding(position);
         }
 
     private Q_SLOTS:
-        void showLmbMenu(int x, int y)
+        void showLmbMenu(int x, int y) override
         {
             m_marbleQuick->selectPlacemarkAt(x, y);
         }
 
-        void showRmbMenu(int, int) {}
-        void openItemToolTip() {}
-        void setCursor(const QCursor &cursor)
+        void showRmbMenu(int, int) override {}
+        void openItemToolTip() override {}
+        void setCursor(const QCursor &cursor) override
         {
             m_marbleQuick->setCursor(cursor);
         }
 
     private Q_SLOTS:
-        void installPluginEventFilter(RenderPlugin *) {}
+        void installPluginEventFilter(RenderPlugin *) override {}
 
     private:
-        bool layersEventFilter(QObject *o, QEvent *e)
+        bool layersEventFilter(QObject *o, QEvent *e) override
         {
             return m_marbleQuick->layersEventFilter(o, e);
         }
 
         //empty - don't check. It would be invalid with quick items
-        void checkReleasedMove(QMouseEvent *) {}
+        void checkReleasedMove(QMouseEvent *) override {}
 
-        bool handleTouch(QTouchEvent *event)
+        bool handleTouch(QTouchEvent *event) override
         {
             if (event->touchPoints().count() > 1)
             {   //not handling multi-touch at all, let PinchArea or MultiPointTouchArea take care of it
@@ -138,7 +141,7 @@ namespace Marble
             return false;
         }
 
-        AbstractSelectionRubber *selectionRubber()
+        AbstractSelectionRubber *selectionRubber() override
         {
             return &m_selectionRubber;
         }
@@ -162,11 +165,41 @@ namespace Marble
             m_placemarkDelegate(nullptr),
             m_placemarkItem(nullptr),
             m_placemark(nullptr),
-            m_reverseGeocoding(&m_model)
+            m_reverseGeocoding(&m_model),
+            m_showScaleBar(false),
+            m_enabledRelationTypes(GeoDataRelation::RouteFerry |
+                            GeoDataRelation::RouteTrain |
+                            GeoDataRelation::RouteSubway |
+                            GeoDataRelation::RouteTram |
+                            GeoDataRelation::RouteBus |
+                            GeoDataRelation::RouteTrolleyBus |
+                            GeoDataRelation::RouteHiking),
+            m_showPublicTransport(false),
+            m_showOutdoorActivities(false)
         {
             m_currentPosition.setName(QObject::tr("Current Location"));
+            m_relationTypeConverter["road"] = GeoDataRelation::RouteRoad;
+            m_relationTypeConverter["detour"] = GeoDataRelation::RouteDetour;
+            m_relationTypeConverter["ferry"] = GeoDataRelation::RouteFerry;
+            m_relationTypeConverter["train"] = GeoDataRelation::RouteTrain;
+            m_relationTypeConverter["subway"] = GeoDataRelation::RouteSubway;
+            m_relationTypeConverter["tram"] = GeoDataRelation::RouteTram;
+            m_relationTypeConverter["bus"] = GeoDataRelation::RouteBus;
+            m_relationTypeConverter["trolley-bus"] = GeoDataRelation::RouteTrolleyBus;
+            m_relationTypeConverter["bicycle"] = GeoDataRelation::RouteBicycle;
+            m_relationTypeConverter["mountainbike"] = GeoDataRelation::RouteMountainbike;
+            m_relationTypeConverter["foot"] = GeoDataRelation::RouteFoot;
+            m_relationTypeConverter["hiking"] = GeoDataRelation::RouteHiking;
+            m_relationTypeConverter["horse"] = GeoDataRelation::RouteHorse;
+            m_relationTypeConverter["inline-skates"] = GeoDataRelation::RouteInlineSkates;
+            m_relationTypeConverter["downhill"] = GeoDataRelation::RouteSkiDownhill;
+            m_relationTypeConverter["ski-nordic"] = GeoDataRelation::RouteSkiNordic;
+            m_relationTypeConverter["skitour"] = GeoDataRelation::RouteSkitour;
+            m_relationTypeConverter["sled"] = GeoDataRelation::RouteSled;
         }
 
+        void updateVisibleRoutes();
+
     private:
         MarbleQuickItem *m_marble;
         friend class MarbleQuickItem;
@@ -181,6 +214,12 @@ namespace Marble
         QQuickItem* m_placemarkItem;
         Placemark* m_placemark;
         ReverseGeocodingRunnerManager m_reverseGeocoding;
+
+        bool m_showScaleBar;
+        QMap<QString, GeoDataRelation::RelationType> m_relationTypeConverter;
+        GeoDataRelation::RelationTypes m_enabledRelationTypes;
+        bool m_showPublicTransport;
+        bool m_showOutdoorActivities;
     };
 
     MarbleQuickItem::MarbleQuickItem(QQuickItem *parent) : QQuickPaintedItem(parent)
@@ -190,7 +229,7 @@ namespace Marble
         setOpaquePainting(true);
         qRegisterMetaType<Placemark*>("Placemark*");
 
-        foreach (AbstractFloatItem *item, d->m_map.floatItems()) {
+        for (AbstractFloatItem *item: d->m_map.floatItems()) {
             if (item->nameId() == QLatin1String("license")) {
                 item->setPosition(QPointF(5.0, -10.0));
             } else {
@@ -201,12 +240,12 @@ namespace Marble
         d->m_model.positionTracking()->setTrackVisible(false);
 
         connect(&d->m_map, SIGNAL(repaintNeeded(QRegion)), this, SLOT(update()));
-        connect(this, SIGNAL(widthChanged()), this, SLOT(resizeMap()));
-        connect(this, SIGNAL(heightChanged()), this, SLOT(resizeMap()));
-        connect(&d->m_map, SIGNAL(visibleLatLonAltBoxChanged(GeoDataLatLonAltBox)), this, SLOT(updatePositionVisibility()));
-        connect(&d->m_map, SIGNAL(visibleLatLonAltBoxChanged(GeoDataLatLonAltBox)), this, SIGNAL(visibleLatLonAltBoxChanged()));
-        connect(&d->m_map, SIGNAL(radiusChanged(int)), this, SIGNAL(radiusChanged(int)));
-        connect(&d->m_map, SIGNAL(radiusChanged(int)), this, SIGNAL(zoomChanged()));
+        connect(this, &MarbleQuickItem::widthChanged, this, &MarbleQuickItem::resizeMap);
+        connect(this, &MarbleQuickItem::heightChanged, this, &MarbleQuickItem::resizeMap);
+        connect(&d->m_map, &MarbleMap::visibleLatLonAltBoxChanged, this, &MarbleQuickItem::updatePositionVisibility);
+        connect(&d->m_map, &MarbleMap::visibleLatLonAltBoxChanged, this, &MarbleQuickItem::visibleLatLonAltBoxChanged);
+        connect(&d->m_map, &MarbleMap::radiusChanged, this, &MarbleQuickItem::radiusChanged);
+        connect(&d->m_map, &MarbleMap::radiusChanged, this, &MarbleQuickItem::zoomChanged);
         connect(&d->m_reverseGeocoding, SIGNAL(reverseGeocodingFinished(GeoDataCoordinates,GeoDataPlacemark)),
                 this, SLOT(handleReverseGeocoding(GeoDataCoordinates,GeoDataPlacemark)));
 
@@ -216,24 +255,15 @@ namespace Marble
 
     void MarbleQuickItem::resizeMap()
     {
-        const int minWidth = 100;
-        const int minHeight = 100;
-        int newWidth = width() > minWidth ? (int)width() : minWidth;
-        int newHeight = height() > minHeight ? (int)height() : minHeight;
-
-        d->m_map.setSize(newWidth, newHeight);
+        d->m_map.setSize(qMax(100, int(width())), qMax(100, int(height())));
         update();
         updatePositionVisibility();
     }
 
     void MarbleQuickItem::positionDataStatusChanged(PositionProviderStatus status)
     {
-        if (status == PositionProviderStatusAvailable) {
-            emit positionAvailableChanged(true);
-        }
-        else {
-            emit positionAvailableChanged(false);
-        }
+        bool const positionAvailable = status == PositionProviderStatusAvailable;
+        emit positionAvailableChanged(positionAvailable);
         updatePositionVisibility();
     }
 
@@ -247,9 +277,10 @@ namespace Marble
         updatePlacemarks();
         bool isVisible = false;
         if ( positionAvailable() ) {
-            if ( d->m_map.viewport()->viewLatLonAltBox().contains(d->m_model.positionTracking()->currentLocation()) ) {
-                isVisible = true;
-            }
+            qreal x, y;
+            bool globeHidesPoint;
+            bool const valid = d->m_map.viewport()->screenCoordinates(d->m_model.positionTracking()->currentLocation(), x, y, globeHidesPoint);
+            isVisible = valid && !globeHidesPoint;
         }
 
         if ( isVisible != d->m_positionVisible ) {
@@ -339,7 +370,7 @@ namespace Marble
 
     MarbleQuickItem::Projection MarbleQuickItem::projection() const
     {
-        return (Projection)d->m_map.projection();
+        return Projection(d->m_map.projection());
     }
 
     QString MarbleQuickItem::mapThemeId() const
@@ -384,7 +415,7 @@ namespace Marble
 
     bool MarbleQuickItem::showScaleBar() const
     {
-        return d->m_map.showScaleBar();
+        return d->m_showScaleBar;
     }
 
     bool MarbleQuickItem::showBackground() const
@@ -395,7 +426,7 @@ namespace Marble
     bool MarbleQuickItem::showPositionMarker() const
     {
         QList<RenderPlugin *> plugins = d->m_map.renderPlugins();
-        foreach (const RenderPlugin * plugin, plugins) {
+        for (const RenderPlugin * plugin: plugins) {
             if (plugin->nameId() == QLatin1String("positionMarker")) {
                 return plugin->visible();
             }
@@ -403,6 +434,16 @@ namespace Marble
         return false;
     }
 
+    bool MarbleQuickItem::showPublicTransport() const
+    {
+        return d->m_showPublicTransport;
+    }
+
+    bool MarbleQuickItem::showOutdoorActivities() const
+    {
+        return d->m_showOutdoorActivities;
+    }
+
     QString MarbleQuickItem::positionProvider() const
     {
         if ( d->m_model.positionTracking()->positionProviderPlugin() ) {
@@ -437,6 +478,11 @@ namespace Marble
         return d->m_inputHandler.inertialEarthRotationEnabled();
     }
 
+    bool MarbleQuickItem::animationViewContext() const
+    {
+        return d->m_map.viewContext() == Animation;
+    }
+
     QQmlComponent *MarbleQuickItem::placemarkDelegate() const
     {
         return d->m_placemarkDelegate;
@@ -462,7 +508,7 @@ namespace Marble
 
     qreal MarbleQuickItem::angle() const
     {
-        bool routeExists = d->m_model.routingManager()->routingModel()->route().distance() != 0;
+        bool routeExists = d->m_model.routingManager()->routingModel()->route().distance() != 0.0;
         bool onRoute = !d->m_model.routingManager()->routingModel()->deviatedFromRoute();
         if ( routeExists && onRoute) {
             GeoDataCoordinates curPoint = d->m_model.positionTracking()->positionProviderPlugin()->position();
@@ -579,29 +625,21 @@ namespace Marble
     void MarbleQuickItem::selectPlacemarkAt(int x, int y)
     {
         auto features = d->m_map.whichFeatureAt(QPoint(x, y));
-        if (features.empty()) {
-            features = d->m_map.whichBuildingAt(QPoint(x, y));
-        }
         QVector<GeoDataPlacemark const *> placemarks;
-        foreach(auto feature, features) {
-            if (feature->nodeType() == GeoDataTypes::GeoDataPlacemarkType) {
-                placemarks << static_cast<const GeoDataPlacemark*>(feature);
+        for(auto feature: features) {
+            if (const auto placemark = geodata_cast<GeoDataPlacemark>(feature)) {
+                placemarks << placemark;
             }
         }
 
-        // Select bookmarks only if nothing else is found
-        qSort(placemarks.begin(), placemarks.end(), [] (GeoDataPlacemark const *a, GeoDataPlacemark const *b) {
-            int const left = a->visualCategory() == GeoDataPlacemark::Bookmark ? -1 : a->visualCategory();
-            int const right = b->visualCategory() == GeoDataPlacemark::Bookmark ? -1 : b->visualCategory();
-            return left > right;
-        });
-
-        foreach(auto placemark, placemarks) {
+        for(auto placemark: placemarks) {
             if (d->m_placemark && placemark->coordinate() == d->m_placemark->placemark().coordinate()) {
                 d->m_placemark->deleteLater();
                 d->m_placemark = nullptr;
             } else {
-                d->m_placemark->deleteLater();
+                if (d->m_placemark) {
+                    d->m_placemark->deleteLater();
+                }
                 d->m_placemark = new Placemark(this);
                 d->m_placemark->setGeoDataPlacemark(*placemark);
             }
@@ -688,7 +726,7 @@ namespace Marble
             return;
         }
 
-        d->m_map.setProjection((Marble::Projection)projection);
+        d->m_map.setProjection(Marble::Projection(projection));
         emit projectionChanged(projection);
     }
 
@@ -702,7 +740,6 @@ namespace Marble
         bool const showOverviewMap = d->m_map.showOverviewMap();
         bool const showOtherPlaces = d->m_map.showOtherPlaces();
         bool const showGrid = d->m_map.showGrid();
-        bool const showScaleBar = d->m_map.showScaleBar();
 
         d->m_map.setMapThemeId(mapThemeId);
 
@@ -711,7 +748,7 @@ namespace Marble
         d->m_map.setShowOverviewMap(showOverviewMap);
         d->m_map.setShowOtherPlaces(showOtherPlaces);
         d->m_map.setShowGrid(showGrid);
-        d->m_map.setShowScaleBar(showScaleBar);
+        d->m_map.setShowScaleBar(d->m_showScaleBar);
 
         emit mapThemeIdChanged(mapThemeId);
     }
@@ -788,11 +825,12 @@ namespace Marble
 
     void MarbleQuickItem::setShowScaleBar(bool showScaleBar)
     {
-        if (this->showScaleBar() == showScaleBar) {
+        if (d->m_showScaleBar == showScaleBar) {
             return;
         }
 
-        d->m_map.setShowScaleBar(showScaleBar);
+        d->m_showScaleBar = showScaleBar;
+        d->m_map.setShowScaleBar(d->m_showScaleBar);
         emit showScaleBarChanged(showScaleBar);
     }
 
@@ -813,7 +851,7 @@ namespace Marble
         }
 
         QList<RenderPlugin *> plugins = d->m_map.renderPlugins();
-        foreach ( RenderPlugin * plugin, plugins ) {
+        for ( RenderPlugin * plugin: plugins ) {
             if (plugin->nameId() == QLatin1String("positionMarker")) {
                 plugin->setVisible(showPositionMarker);
                 break;
@@ -823,6 +861,24 @@ namespace Marble
         emit showPositionMarkerChanged(showPositionMarker);
     }
 
+    void MarbleQuickItem::setShowPublicTransport(bool enabled)
+    {
+        if (d->m_showPublicTransport != enabled) {
+            d->m_showPublicTransport = enabled;
+            d->updateVisibleRoutes();
+            emit showPublicTransportChanged(enabled);
+        }
+    }
+
+    void MarbleQuickItem::setShowOutdoorActivities(bool showOutdoorActivities)
+    {
+        if (d->m_showOutdoorActivities != showOutdoorActivities) {
+            d->m_showOutdoorActivities = showOutdoorActivities;
+            d->updateVisibleRoutes();
+            emit showOutdoorActivitiesChanged(showOutdoorActivities);
+        }
+    }
+
     void MarbleQuickItem::setPositionProvider(const QString &positionProvider)
     {
         QString name;
@@ -839,7 +895,7 @@ namespace Marble
         }
 
         QList<const PositionProviderPlugin*> plugins = d->m_model.pluginManager()->positionProviderPlugins();
-        foreach (const PositionProviderPlugin* plugin, plugins) {
+        for (const PositionProviderPlugin* plugin: plugins) {
             if ( plugin->nameId() == positionProvider) {
                 PositionProviderPlugin * newPlugin = plugin->newInstance();
                 d->m_model.positionTracking()->setPositionProviderPlugin(newPlugin);
@@ -863,9 +919,16 @@ namespace Marble
         emit inertialGlobeRotationChanged(inertialGlobeRotation);
     }
 
+    void MarbleQuickItem::setAnimationViewContext(bool animationViewContext)
+    {
+        d->m_map.setViewContext(animationViewContext ? Animation : Still );
+
+        emit inertialGlobeRotationChanged(animationViewContext);
+    }
+
     void MarbleQuickItem::setPluginSetting(const QString &pluginId, const QString &key, const QString &value)
     {
-        foreach (RenderPlugin* plugin, d->m_map.renderPlugins()) {
+        for (RenderPlugin* plugin: d->m_map.renderPlugins()) {
             if (plugin->nameId() == pluginId) {
                 plugin->setSetting(key, value);
             }
@@ -933,10 +996,19 @@ namespace Marble
         if (zoom > 0) {
             setZoom(zoom);
         }
+        auto const defaultRelationTypes = QStringList() << "ferry" << "train" << "subway" << "tram" << "bus" << "trolley-bus" << "hiking";
+        auto const visibleRelationTypes = settings.value(QStringLiteral("visibleRelationTypes"), defaultRelationTypes).toStringList();
+        d->m_enabledRelationTypes = GeoDataRelation::UnknownType;
+        for (auto const &route: visibleRelationTypes) {
+            d->m_enabledRelationTypes |= d->m_relationTypeConverter.value(route, GeoDataRelation::UnknownType);
+        }
+        setShowPublicTransport(settings.value(QStringLiteral("showPublicTransport"), false).toBool());
+        setShowOutdoorActivities(settings.value(QStringLiteral("showOutdoorActivities"), false).toBool());
         settings.endGroup();
         d->m_model.routingManager()->readSettings();
         d->m_model.bookmarkManager()->loadFile(QStringLiteral("bookmarks/bookmarks.kml"));
         d->m_model.bookmarkManager()->setShowBookmarks(true);
+        d->updateVisibleRoutes();
     }
 
     void MarbleQuickItem::writeSettings()
@@ -946,10 +1018,51 @@ namespace Marble
         settings.setValue(QStringLiteral("centerLon"), QVariant(d->m_map.centerLongitude()));
         settings.setValue(QStringLiteral("centerLat"), QVariant(d->m_map.centerLatitude()));
         settings.setValue(QStringLiteral("zoom"), QVariant(zoom()));
+        QStringList enabledRoutes;
+        QMap<GeoDataRelation::RelationType, QString> relationConverter;
+        for (auto iter = d->m_relationTypeConverter.cbegin(), end = d->m_relationTypeConverter.cend(); iter != end; ++iter) {
+            relationConverter[iter.value()] = iter.key();
+        }
+        for (auto iter = relationConverter.cbegin(), end = relationConverter.cend(); iter != end; ++iter) {
+            if (d->m_enabledRelationTypes & iter.key()) {
+                enabledRoutes << iter.value();
+            }
+        }
+        settings.setValue(QStringLiteral("visibleRelationTypes"), enabledRoutes);
+        settings.setValue(QStringLiteral("showPublicTransport"), d->m_showPublicTransport);
+        settings.setValue(QStringLiteral("showOutdoorActivities"), d->m_showOutdoorActivities);
+
         settings.endGroup();
         d->m_model.routingManager()->writeSettings();
     }
 
+    void MarbleQuickItem::reloadTiles()
+    {
+        d->m_map.reload();
+    }
+
+    void MarbleQuickItem::highlightRouteRelation(qint64 osmId, bool enabled)
+    {
+        d->m_map.highlightRouteRelation(osmId, enabled);
+    }
+
+    void MarbleQuickItem::setRelationTypeVisible(const QString &relationType, bool visible)
+    {
+        auto const relation = d->m_relationTypeConverter.value(relationType, GeoDataRelation::UnknownType);
+        if (visible) {
+            d->m_enabledRelationTypes |= relation;
+        } else {
+            d->m_enabledRelationTypes &= ~relation;
+        }
+        d->updateVisibleRoutes();
+    }
+
+    bool MarbleQuickItem::isRelationTypeVisible(const QString &relationType) const
+    {
+        auto const relation = d->m_relationTypeConverter.value(relationType, GeoDataRelation::UnknownType);
+        return d->m_enabledRelationTypes & relation;
+    }
+
     QObject *MarbleQuickItem::getEventFilter() const
     {   //We would want to install the same event filter for abstract layer QuickItems such as PinchArea
         return &d->m_inputHandler;
@@ -979,4 +1092,36 @@ namespace Marble
     {   //Does nothing, but can be reimplemented in a subclass
         return false;
     }
+
+    QuickItemSelectionRubber::QuickItemSelectionRubber() :
+        m_visible(false)
+    {
+        // nothing to do
+    }
+
+    void MarbleQuickItemPrivate::updateVisibleRoutes()
+    {
+        GeoDataRelation::RelationTypes relationTypes = m_enabledRelationTypes;
+        if (!m_showPublicTransport) {
+            relationTypes &= ~GeoDataRelation::RouteTrain;
+            relationTypes &= ~GeoDataRelation::RouteSubway;
+            relationTypes &= ~GeoDataRelation::RouteTram;
+            relationTypes &= ~GeoDataRelation::RouteBus;
+            relationTypes &= ~GeoDataRelation::RouteTrolleyBus;
+        }
+        if (!m_showOutdoorActivities) {
+            relationTypes &= ~GeoDataRelation::RouteBicycle;
+            relationTypes &= ~GeoDataRelation::RouteMountainbike;
+            relationTypes &= ~GeoDataRelation::RouteFoot;
+            relationTypes &= ~GeoDataRelation::RouteHiking;
+            relationTypes &= ~GeoDataRelation::RouteHorse;
+            relationTypes &= ~GeoDataRelation::RouteInlineSkates;
+            relationTypes &= ~GeoDataRelation::RouteSkiDownhill;
+            relationTypes &= ~GeoDataRelation::RouteSkiNordic;
+            relationTypes &= ~GeoDataRelation::RouteSkitour;
+            relationTypes &= ~GeoDataRelation::RouteSled;
+        }
+        m_map.setVisibleRelationTypes(relationTypes);
+    }
+
 }
