@@ -306,10 +306,7 @@ bool GeoDataLatLonBox::crossesDateLine() const
 
 bool GeoDataLatLonBox::crossesDateLine(qreal east, qreal west)
 {
-    if ( east < west || ( east == M_PI && west == -M_PI ) ) {
-        return true;
-    }
-    return false;
+    return east < west || ( east == M_PI && west == -M_PI );
 }
 
 GeoDataCoordinates GeoDataLatLonBox::center() const
@@ -347,15 +344,16 @@ bool GeoDataLatLonBox::containsPole( Pole pole ) const
 
 bool GeoDataLatLonBox::contains(qreal lon, qreal lat) const
 {
+    if ( lat < d->m_south || lat > d->m_north ) {
+        return false;
+    }
+
     // We need to take care of the normal case ...
     if ( ( ( lon < d->m_west || lon > d->m_east ) && ( d->m_west < d->m_east ) ) ||
     // ... and the case where the bounding box crosses the date line:
          ( ( lon < d->m_west && lon > d->m_east ) && ( d->m_west > d->m_east ) ) )
         return false;
 
-    if ( lat < d->m_south || lat > d->m_north )
-        return false;
-
     return true;
 }
 
@@ -574,7 +572,7 @@ GeoDataLatLonBox GeoDataLatLonBox::toCircumscribedRectangle() const
     bool eastSet = false;
     bool westSet = false;
 
-    foreach ( const GeoDataCoordinates& coord, coordinates ) {
+    for ( const GeoDataCoordinates& coord: coordinates ) {
 
         const qreal lon = coord.longitude();
         const qreal lat = coord.latitude();
@@ -807,10 +805,7 @@ GeoDataLatLonBox GeoDataLatLonBox::fromLineString(  const GeoDataLineString& lin
 
 bool GeoDataLatLonBox::isNull() const
 {
-    if ( d->m_north == d->m_south && d->m_east == d->m_west )
-        return true;
-
-    return false;
+    return d->m_north == d->m_south && d->m_east == d->m_west;
 }
 
 bool GeoDataLatLonBox::isEmpty() const
@@ -818,6 +813,66 @@ bool GeoDataLatLonBox::isEmpty() const
     return *this == empty;
 }
 
+bool GeoDataLatLonBox::fuzzyCompare(const GeoDataLatLonBox& lhs,
+                                           const GeoDataLatLonBox& rhs,
+                                           const qreal factor)
+{
+    bool equal = true;
+
+    // Check the latitude for approximate equality
+
+    double latDelta = lhs.height() * factor;
+
+    if (fabs(lhs.north() - rhs.north()) > latDelta) equal = false;
+    if (fabs(lhs.south() - rhs.south()) > latDelta) equal = false;
+
+
+    // Check the longitude for approximate equality
+
+    double lonDelta = lhs.width() * factor;
+
+    double lhsEast = lhs.east();
+    double rhsEast = rhs.east();
+
+    if (!GeoDataLatLonBox::crossesDateLine(lhsEast, rhsEast)) {
+        if (fabs(lhsEast - rhsEast) > lonDelta) equal = false;
+    }
+    else {
+        lhsEast = GeoDataCoordinates::normalizeLat( lhsEast );
+        rhsEast = GeoDataCoordinates::normalizeLat( rhsEast );
+        if (lhsEast < 0 && rhsEast > 0) {
+            lhsEast += 2 * M_PI;
+            if (fabs(lhsEast - rhsEast) > lonDelta) equal = false;
+        }
+        if (lhsEast > 0 && rhsEast < 0) {
+            rhsEast += 2 * M_PI;
+            if (fabs(lhsEast - rhsEast) > lonDelta) equal = false;
+        }
+    }
+
+    double lhsWest = lhs.west();
+    double rhsWest = rhs.west();
+
+    if (!GeoDataLatLonBox::crossesDateLine(lhsWest, rhsWest)) {
+       if (fabs(lhsWest - rhsWest) > lonDelta) equal = false;
+    }
+    else {
+        lhsWest = GeoDataCoordinates::normalizeLat( lhsWest );
+        rhsWest = GeoDataCoordinates::normalizeLat( rhsWest );
+        if (lhsWest < 0 && rhsWest > 0) {
+            lhsWest += 2 * M_PI;
+            if (fabs(lhsWest - rhsWest) > lonDelta) equal = false;
+        }
+        if (lhsWest > 0 && rhsWest < 0) {
+            rhsWest += 2 * M_PI;
+            if (fabs(lhsWest - rhsWest) > lonDelta) equal = false;
+        }
+    }
+
+    return equal;
+}
+
+
 void GeoDataLatLonBox::clear()
 {
     *this = empty;
