@@ -558,12 +558,10 @@ void GeoDataLineString::setTessellate( bool tessellate )
     // the same latitude the latitude circles are followed. Our Tesselate and RespectLatitude
     // Flags provide this behaviour. For true polygons the latitude circles don't get considered.
 
-    if ( tessellate ) {
-        d->m_tessellationFlags |= Tessellate;
-        d->m_tessellationFlags |= RespectLatitudeCircle;
+    if (tessellate) {
+        d->m_tessellationFlags |= (Tessellate | RespectLatitudeCircle);
     } else {
-        d->m_tessellationFlags ^= Tessellate;
-        d->m_tessellationFlags ^= RespectLatitudeCircle;
+        d->m_tessellationFlags &= ~(Tessellate | RespectLatitudeCircle);
     }
 }
 
