@@ -30,7 +30,7 @@ KML_DEFINE_TAG_HANDLER_GX22( TimeStamp )
 
 GeoNode* KmlTimeStampTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_TimeStamp ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_TimeStamp)));
     GeoStackItem parentItem = parser.parentElement();
     GeoDataTimeStamp timestamp;
     KmlObjectTagHandler::parseIdentifiers( parser, &timestamp );
