@@ -24,7 +24,7 @@ KML_DEFINE_TAG_HANDLER( north )
 
 GeoNode* KmlnorthTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_north ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_north)));
 
     GeoStackItem parentItem = parser.parentElement();
 
