@@ -25,7 +25,7 @@ KML_DEFINE_TAG_HANDLER( Update )
 
 GeoNode* KmlUpdateTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_Update ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Update)));
 
     GeoDataUpdate *update = new GeoDataUpdate;
     KmlObjectTagHandler::parseIdentifiers( parser, update );
