@@ -891,7 +891,7 @@ void KDescendantsProxyModelPrivate::sourceLayoutAboutToBeChanged()
     }
 
     QPersistentModelIndex srcPersistentIndex;
-    Q_FOREACH (const QPersistentModelIndex &proxyPersistentIndex, q->persistentIndexList()) {
+    for (const QPersistentModelIndex &proxyPersistentIndex: q->persistentIndexList()) {
         m_proxyIndexes << proxyPersistentIndex;
         Q_ASSERT(proxyPersistentIndex.isValid());
         srcPersistentIndex = q->mapToSource(proxyPersistentIndex);
@@ -964,7 +964,7 @@ QMimeData *KDescendantsProxyModel::mimeData(const QModelIndexList &indexes) cons
     }
     Q_ASSERT(sourceModel());
     QModelIndexList sourceIndexes;
-    Q_FOREACH (const QModelIndex &index, indexes) {
+    for (const QModelIndex &index: indexes) {
         sourceIndexes << mapToSource(index);
     }
     return sourceModel()->mimeData(sourceIndexes);
