@@ -34,9 +34,9 @@
 #include "GeoDataStyle.h"
 #include "GeoDataLabelStyle.h"
 #include "GeoDataLineStyle.h"
+#include "GeoDataPoint.h"
 #include "GeoDataPolyStyle.h"
 #include "GeoDataTreeModel.h"
-#include "GeoDataTypes.h"
 #include "GeoPainter.h"
 #include "GeoDataLatLonAltBox.h"
 #include "GeoDataLinearRing.h"
@@ -59,6 +59,7 @@
 #include "ParsingRunnerManager.h"
 #include "ViewportParams.h"
 #include "osm/OsmPlacemarkData.h"
+#include "DownloadOsmDialog.h"
 
 namespace Marble
 {
@@ -106,10 +107,9 @@ AnnotatePlugin::~AnnotatePlugin()
     // delete m_networkAccessManager;
 
     delete m_clipboardItem;
+    qDeleteAll(m_actions);
 
-    if ( m_marbleWidget ) {
-        disconnect( this, SIGNAL(mouseMoveGeoPosition(QString)), m_marbleWidget, SIGNAL(mouseMoveGeoPosition(QString)) );
-    }
+    disconnect( this, SIGNAL(mouseMoveGeoPosition(QString)), m_marbleWidget, SIGNAL(mouseMoveGeoPosition(QString)) );
 }
 
 QStringList AnnotatePlugin::backendTypes() const
@@ -240,14 +240,14 @@ const QList<QActionGroup*> *AnnotatePlugin::actionGroups() const
     return &m_actions;
 }
 
-bool AnnotatePlugin::render( GeoPainter *painter, ViewportParams *viewport, const QString &renderPos, GeoSceneLayer *layer )
+bool AnnotatePlugin::render(GeoPainter *painter, ViewportParams *viewport, const QString &renderPos, GeoSceneLayer *layer)
 {
     Q_UNUSED( renderPos );
     Q_UNUSED( layer );
 
     QListIterator<SceneGraphicsItem*> iter( m_graphicsItems );
     while ( iter.hasNext() ) {
-        iter.next()->paint( painter, viewport, "Annotation" );
+        iter.next()->paint( painter, viewport, "Annotation", -1 );
     }
 
     return true;
@@ -407,30 +407,45 @@ void AnnotatePlugin::loadAnnotationFile()
     if ( filename.isNull() ) {
         return;
     }
+    else{
+        openAnnotationFile(filename);
+    }
+}
 
-    ParsingRunnerManager manager( m_marbleWidget->model()->pluginManager() );
-    GeoDataDocument *document = manager.openFile( filename );
+void AnnotatePlugin::downloadOsm()
+{
+    QPointer<DownloadOsmDialog> dialog=new DownloadOsmDialog(m_marbleWidget,this);
+    dialog->show();
+}
+
+void AnnotatePlugin::openAnnotationFile(const QString& filename)
+{
+
+    if ( filename.isNull() ) {
+        return;
+    }
+    ParsingRunnerManager manager( m_marbleWidget->model()->pluginManager(),this );
+    GeoDataDocument *document = manager.openFile( filename);
     Q_ASSERT( document );
 
     // FIXME: The same problem as in the case of copying/cutting graphic items applies here:
     // the files do not load properly because the geometry copy is not a deep copy.
     foreach ( GeoDataFeature *feature, document->featureList() ) {
 
-        if ( feature->nodeType() == GeoDataTypes::GeoDataPlacemarkType ) {
-            GeoDataPlacemark *placemark = static_cast<GeoDataPlacemark*>( feature );
+        if (const GeoDataPlacemark *placemark = geodata_cast<GeoDataPlacemark>(feature)) {
             GeoDataPlacemark *newPlacemark = new GeoDataPlacemark( *placemark );
 
-            if ( placemark->geometry()->nodeType() == GeoDataTypes::GeoDataPointType ) {
+            if (geodata_cast<GeoDataPoint>(placemark->geometry())) {
                 PlacemarkTextAnnotation *placemark = new PlacemarkTextAnnotation( newPlacemark );
                 m_graphicsItems.append( placemark );
-            } else if ( placemark->geometry()->nodeType() == GeoDataTypes::GeoDataPolygonType ) {
+            } else if (geodata_cast<GeoDataPolygon>(placemark->geometry())) {
                 newPlacemark->setParent( m_annotationDocument );
                 if ( !placemark->styleUrl().isEmpty() ) {
                     newPlacemark->setStyleUrl( placemark->styleUrl() );
                 }
                 AreaAnnotation *polygonAnnotation = new AreaAnnotation( newPlacemark );
                 m_graphicsItems.append( polygonAnnotation );
-            } else if ( placemark->geometry()->nodeType() == GeoDataTypes::GeoDataLineStringType ) {
+            } else if (geodata_cast<GeoDataLineString>(placemark->geometry())) {
                 newPlacemark->setParent( m_annotationDocument );
                 if ( !placemark->styleUrl().isEmpty() ) {
                     newPlacemark->setStyleUrl( placemark->styleUrl() );
@@ -439,8 +454,7 @@ void AnnotatePlugin::loadAnnotationFile()
                 m_graphicsItems.append( polylineAnnotation );
             }
             m_marbleWidget->model()->treeModel()->addFeature( m_annotationDocument, newPlacemark );
-        } else if ( feature->nodeType() == GeoDataTypes::GeoDataGroundOverlayType ) {
-            GeoDataGroundOverlay *overlay = static_cast<GeoDataGroundOverlay*>( feature );
+        } else if (const GeoDataGroundOverlay *overlay = geodata_cast<GeoDataGroundOverlay>(feature)) {
             GeoDataGroundOverlay *newOverlay = new GeoDataGroundOverlay( *overlay );
             m_marbleWidget->model()->treeModel()->addFeature( m_annotationDocument, newOverlay );
             displayOverlayFrame( newOverlay );
@@ -571,7 +585,7 @@ bool AnnotatePlugin::eventFilter( QObject *watched, QEvent *event )
     }
 
     // Pass the event to Graphic Items.
-    foreach ( SceneGraphicsItem *item, m_graphicsItems ) {
+    for ( SceneGraphicsItem *item: m_graphicsItems ) {
         if ( !item->containsPoint( mouseEvent->pos() ) ) {
             continue;
         }
@@ -946,6 +960,11 @@ void AnnotatePlugin::setupActions( MarbleWidget *widget )
     QAction *clearAnnotations = new QAction( QIcon(QStringLiteral(":/icons/remove.png")),
                                              tr("Clear all Annotations"),
                                              this );
+    QAction *downloadOsm = new QAction( QIcon(":/icons/download.png"),
+                                           tr("Download OpenStreetMap Data"),
+                                           this );
+    connect( downloadOsm, SIGNAL(triggered(bool)), this, SLOT(downloadOsm()) );
+    downloadOsm->setToolTip(tr("Download OpenStreetMap data of the visible region"));
     connect( drawPolygon, SIGNAL(toggled(bool)), clearAnnotations, SLOT(setDisabled(bool)) );
     connect( clearAnnotations, SIGNAL(triggered()), this, SLOT(clearAnnotations()) );
 
@@ -975,6 +994,7 @@ void AnnotatePlugin::setupActions( MarbleWidget *widget )
     group->addAction( removeItem );
     group->addAction( sep3 );
     group->addAction( clearAnnotations );
+    group->addAction(downloadOsm);
     group->addAction( sep4 );
 
     m_actions.append( group );
@@ -1275,7 +1295,7 @@ void AnnotatePlugin::updateOverlayFrame( GeoDataGroundOverlay *overlay )
 
 void AnnotatePlugin::clearOverlayFrames()
 {
-    foreach ( GeoDataGroundOverlay *overlay, m_groundOverlayFrames.keys() ) {
+    for ( GeoDataGroundOverlay *overlay: m_groundOverlayFrames.keys() ) {
         GroundOverlayFrame *frame = static_cast<GroundOverlayFrame *>( m_groundOverlayFrames.value( overlay ) );
         m_graphicsItems.removeAll( m_groundOverlayFrames.value( overlay ) );
         m_marbleWidget->model()->treeModel()->removeFeature( frame->placemark() );
@@ -1677,7 +1697,7 @@ void AnnotatePlugin::addRelation( const OsmPlacemarkData &relationData )
 
 void AnnotatePlugin::announceStateChanged( SceneGraphicsItem::ActionState newState )
 {
-    foreach ( SceneGraphicsItem *item, m_graphicsItems ) {
+    for ( SceneGraphicsItem *item: m_graphicsItems ) {
         item->setState( newState );
         m_marbleWidget->model()->treeModel()->updateFeature( item->placemark() );
     }
