@@ -23,7 +23,6 @@
 #include "MarbleMath.h"
 #include "GeoDataLineString.h"
 #include "GeoDataPlacemark.h"
-#include "GeoDataTypes.h"
 #include "ViewportParams.h"
 #include "MergingPolylineNodesAnimation.h"
 #include "osm/OsmPlacemarkData.h"
@@ -58,11 +57,12 @@ PolylineAnnotation::~PolylineAnnotation()
     delete m_animation;
 }
 
-void PolylineAnnotation::paint(GeoPainter *painter, const ViewportParams *viewport , const QString &layer)
+void PolylineAnnotation::paint(GeoPainter *painter, const ViewportParams *viewport , const QString &layer, int tileZoomLevel)
 {
     Q_UNUSED(layer);
+    Q_UNUSED(tileZoomLevel);
     m_viewport = viewport;
-    Q_ASSERT( placemark()->geometry()->nodeType() == GeoDataTypes::GeoDataLineStringType );
+    Q_ASSERT(geodata_cast<GeoDataLineString>(placemark()->geometry()));
 
     painter->save();
     if ( state() == SceneGraphicsItem::DrawingPolyline || !m_regionsInitialized ) {
