@@ -33,7 +33,7 @@ namespace Marble
 class OutlinedStyle : public QCommonStyle {
 public:
     void drawItemText( QPainter *painter, const QRect &rect, int alignment, const QPalette &palette,
-                       bool enabled, const QString& text, QPalette::ColorRole textRole ) const {
+                       bool enabled, const QString& text, QPalette::ColorRole textRole ) const override {
         Q_UNUSED( alignment );
         Q_UNUSED( enabled );
 
@@ -136,7 +136,9 @@ void License::initialize ()
     delete m_widgetItem;
     m_widgetItem = new WidgetGraphicsItem( this );
     m_label = new QLabel;
-    m_label->setStyle( new OutlinedStyle );
+    auto style = new OutlinedStyle;
+    style->setParent(this);
+    m_label->setStyle( style );
     m_label->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed );
     m_widgetItem->setWidget( m_label );
 
