@@ -20,6 +20,7 @@
 #include "GeoDataLinearRing.h"
 #include "MarbleDebug.h"
 #include "MarbleMath.h"
+#include "MarbleWidgetPopupMenu.h"
 #include "MarbleModel.h"
 #include "MarbleLocale.h"
 #include "ViewportParams.h"
@@ -36,13 +37,12 @@ namespace Marble
 MeasureToolPlugin::MeasureToolPlugin( const MarbleModel *marbleModel )
     : RenderPlugin( marbleModel ),
       m_measureLineString( GeoDataLineString( Tessellate ) ),
-      m_mark( ":/mark.png" ),
 #ifdef Q_OS_MACX
       m_font_regular( QFont( QStringLiteral( "Sans Serif" ), 10, 50, false ) ),
 #else
       m_font_regular( QFont( QStringLiteral( "Sans Serif" ),  8, 50, false ) ),
 #endif
-      m_fontascent( QFontMetrics( m_font_regular ).ascent() ),
+      m_fontascent(-1),
       m_pen( Qt::red ),
       m_addMeasurePointAction( 0 ),
       m_removeLastMeasurePointAction( 0 ),
@@ -71,17 +71,17 @@ MeasureToolPlugin::MeasureToolPlugin( const MarbleModel *marbleModel )
 
 QStringList MeasureToolPlugin::backendTypes() const
 {
-    return QStringList( "measuretool" );
+    return QStringList(QStringLiteral("measuretool"));
 }
 
 QString MeasureToolPlugin::renderPolicy() const
 {
-    return QString( "ALWAYS" );
+    return QStringLiteral("ALWAYS");
 }
 
 QStringList MeasureToolPlugin::renderPosition() const
 {
-    return QStringList() << "ATMOSPHERE";
+    return QStringList(QStringLiteral("ATMOSPHERE"));
 }
 
 QString MeasureToolPlugin::name() const
@@ -96,12 +96,12 @@ QString MeasureToolPlugin::guiString() const
 
 QString MeasureToolPlugin::nameId() const
 {
-    return QString( "measure-tool" );
+    return QStringLiteral("measure-tool");
 }
 
 QString MeasureToolPlugin::version() const
 {
-    return "1.0";
+    return QStringLiteral("1.0");
 }
 
 QString MeasureToolPlugin::description() const
@@ -111,34 +111,35 @@ QString MeasureToolPlugin::description() const
 
 QString MeasureToolPlugin::copyrightYears() const
 {
-    return "2006-2008, 2011";
+    return QStringLiteral("2006-2008, 2011");
 }
 
-QList<PluginAuthor> MeasureToolPlugin::pluginAuthors() const
+QVector<PluginAuthor> MeasureToolPlugin::pluginAuthors() const
 {
-    return QList<PluginAuthor>()
-            << PluginAuthor( QString::fromUtf8( "Dennis Nienhüser" ), "nienhueser@kde.org" )
-            << PluginAuthor( "Torsten Rahn", "tackat@kde.org" )
-            << PluginAuthor( "Inge Wallin", "ingwa@kde.org" )
-            << PluginAuthor( "Carlos Licea", "carlos.licea@kdemail.net" )
-            << PluginAuthor( "Michael Henning", "mikehenning@eclipse.net" )
-            << PluginAuthor( "Valery Kharitonov", "kharvd@gmail.com" )
-            << PluginAuthor( "Mohammed Nafees", "nafees.technocool@gmail.com" )
-            << PluginAuthor( "Illya Kovalevskyy", "illya.kovalevskyy@gmail.com" );
+    return QVector<PluginAuthor>()
+            << PluginAuthor(QStringLiteral("Dennis Nienhüser"), QStringLiteral("nienhueser@kde.org"))
+            << PluginAuthor(QStringLiteral("Torsten Rahn"), QStringLiteral("tackat@kde.org"))
+            << PluginAuthor(QStringLiteral("Inge Wallin"), QStringLiteral("ingwa@kde.org"))
+            << PluginAuthor(QStringLiteral("Carlos Licea"), QStringLiteral("carlos.licea@kdemail.net"))
+            << PluginAuthor(QStringLiteral("Michael Henning"), QStringLiteral("mikehenning@eclipse.net"))
+            << PluginAuthor(QStringLiteral("Valery Kharitonov"), QStringLiteral("kharvd@gmail.com"))
+            << PluginAuthor(QStringLiteral("Mohammed Nafees"), QStringLiteral("nafees.technocool@gmail.com"))
+            << PluginAuthor(QStringLiteral("Illya Kovalevskyy"), QStringLiteral("illya.kovalevskyy@gmail.com"));
 }
 
 QIcon MeasureToolPlugin::icon () const
 {
-    return QIcon(":/icons/measure.png");
+    return QIcon(QStringLiteral(":/icons/measure.png"));
 }
 
 void MeasureToolPlugin::initialize ()
 {
+     m_fontascent = QFontMetrics( m_font_regular ).ascent();
 }
 
 bool MeasureToolPlugin::isInitialized () const
 {
-    return true;
+    return m_fontascent >= 0;
 }
 
 QDialog *MeasureToolPlugin::configDialog()
@@ -168,15 +169,15 @@ QHash<QString,QVariant> MeasureToolPlugin::settings() const
 {
     QHash<QString, QVariant> settings = RenderPlugin::settings();
 
-    settings.insert( "showDistanceLabel", m_showDistanceLabel );
-    settings.insert( "showBearingLabel", m_showBearingLabel );
-    settings.insert( "showBearingChangeLabel", m_showBearingChangeLabel );
-    settings.insert( "showPolygonArea", m_showPolygonArea );
-    settings.insert( "showCircularArea", m_showCircularArea );
-    settings.insert( "showRadius", m_showRadius );
-    settings.insert( "showPerimeter", m_showPerimeter );
-    settings.insert( "showCircumference", m_showCircumference );
-    settings.insert( "paintMode", (int)m_paintMode );
+    settings.insert(QStringLiteral("showDistanceLabel"), m_showDistanceLabel);
+    settings.insert(QStringLiteral("showBearingLabel"), m_showBearingLabel);
+    settings.insert(QStringLiteral("showBearingChangeLabel"), m_showBearingChangeLabel);
+    settings.insert(QStringLiteral("showPolygonArea"), m_showPolygonArea);
+    settings.insert(QStringLiteral("showCircularArea"), m_showCircularArea);
+    settings.insert(QStringLiteral("showRadius"), m_showRadius);
+    settings.insert(QStringLiteral("showPerimeter"), m_showPerimeter);
+    settings.insert(QStringLiteral("showCircumference"), m_showCircumference);
+    settings.insert(QStringLiteral("paintMode"), (int)m_paintMode);
 
     return settings;
 }
@@ -185,15 +186,15 @@ void MeasureToolPlugin::setSettings( const QHash<QString,QVariant> &settings )
 {
     RenderPlugin::setSettings( settings );
 
-    m_showDistanceLabel = settings.value( "showDistanceLabel", true ).toBool();
-    m_showBearingLabel = settings.value( "showBearingLabel", true ).toBool();
-    m_showBearingChangeLabel = settings.value( "showBearingChangeLabel", true ).toBool();
-    m_showPolygonArea = settings.value( "showPolygonArea", false ).toBool();
-    m_showCircularArea = settings.value( "showCircularArea", true ).toBool();
-    m_showRadius = settings.value( "showRadius", true ).toBool();
-    m_showPerimeter = settings.value( "showPerimeter", true ).toBool();
-    m_showCircumference = settings.value( "showCircumference", true ).toBool();
-    m_paintMode = (PaintMode)settings.value( "paintMode", 0 ).toInt();
+    m_showDistanceLabel = settings.value(QStringLiteral("showDistanceLabel"), true).toBool();
+    m_showBearingLabel = settings.value(QStringLiteral("showBearingLabel"), true).toBool();
+    m_showBearingChangeLabel = settings.value(QStringLiteral("showBearingChangeLabel"), true).toBool();
+    m_showPolygonArea = settings.value(QStringLiteral("showPolygonArea"), false).toBool();
+    m_showCircularArea = settings.value(QStringLiteral("showCircularArea"), true).toBool();
+    m_showRadius = settings.value(QStringLiteral("showRadius"), true).toBool();
+    m_showPerimeter = settings.value(QStringLiteral("showPerimeter"), true).toBool();
+    m_showCircumference = settings.value(QStringLiteral("showCircumference"), true).toBool();
+    m_paintMode = (PaintMode)settings.value(QStringLiteral("paintMode"), 0).toInt();
 }
 
 void MeasureToolPlugin::writeSettings()
@@ -293,7 +294,7 @@ void MeasureToolPlugin::drawSegments( GeoPainter* painter )
             }
             QString bearingString = QString::fromUtf8( "%1°" ).arg( bearing, 0, 'f', 2 );
             if ( !infoString.isEmpty() ) {
-                infoString.append( "\n" );
+                infoString += QLatin1Char('\n');
             }
             infoString.append( bearingString );
         }
@@ -533,15 +534,18 @@ QString MeasureToolPlugin::meterToPreferredUnit(qreal meters, bool isSquare) con
         unitString.append(QChar(0xB2));
     }
 
-    return QString("%L1 %2").arg(convertedMeters, 8, 'f', 1, QChar(' '))
+    return QString("%L1 %2").arg(convertedMeters, 8, 'f', 1, QLatin1Char(' '))
                             .arg(unitString);
 }
 
-void MeasureToolPlugin::drawMeasurePoints( GeoPainter *painter ) const
+void MeasureToolPlugin::drawMeasurePoints( GeoPainter *painter )
 {
     // Paint the marks.
     GeoDataLineString::const_iterator itpoint = m_measureLineString.constBegin();
     GeoDataLineString::const_iterator const endpoint = m_measureLineString.constEnd();
+    if (m_mark.isNull()) {
+        m_mark = QPixmap(QStringLiteral(":/mark.png"));
+    }
     for (; itpoint != endpoint; ++itpoint )
     {
         painter->drawPixmap( *itpoint, m_mark );
@@ -553,9 +557,9 @@ void MeasureToolPlugin::drawInfobox( GeoPainter *painter ) const
     QString boxContent;
 
     if (m_paintMode == Polygon) {
-        boxContent += "<strong>" + tr("Polygon Ruler") + ":</strong><br/>\n";
+        boxContent += QLatin1String("<strong>") + tr("Polygon Ruler") + QLatin1String(":</strong><br/>\n");
     } else /* Circular */ {
-        boxContent += "<strong>" + tr("Circle Ruler") + ":</strong><br/>\n";
+        boxContent += QLatin1String("<strong>") + tr("Circle Ruler") + QLatin1String(":</strong><br/>\n");
     }
     if (m_paintMode == Polygon) {
         boxContent += tr("Total Distance: %1<br/>\n").arg( meterToPreferredUnit(m_totalDistance) );
@@ -617,7 +621,7 @@ void MeasureToolPlugin::addContextItems()
     MarbleWidgetPopupMenu *menu = m_marbleWidget->popupMenu();
 
     // Connect the inputHandler and the measure tool to the popup menu
-    m_addMeasurePointAction = new QAction( QIcon(":/icons/measure.png"), tr( "Add &Measure Point" ), this );
+    m_addMeasurePointAction = new QAction(QIcon(QStringLiteral(":/icons/measure.png")), tr("Add &Measure Point"), this);
     m_removeLastMeasurePointAction = new QAction( tr( "Remove &Last Measure Point" ), this );
     m_removeLastMeasurePointAction->setEnabled( false );
     m_removeMeasurePointsAction = new QAction( tr( "&Remove Measure Points" ), this );
