@@ -31,7 +31,7 @@ class BBCItemGetter : public AbstractWorkerThread
 
  public:
     explicit BBCItemGetter( QObject *parent = 0 );
-    ~BBCItemGetter();
+    ~BBCItemGetter() override;
 
     void setSchedule( const GeoDataLatLonBox& box,
                       qint32 number );
@@ -41,8 +41,8 @@ class BBCItemGetter : public AbstractWorkerThread
     BBCStation station( const QString &id );
 
  protected:
-    bool workAvailable();
-    void work();
+    bool workAvailable() override;
+    void work() override;
 
  Q_SIGNALS:
     void foundStation( const BBCStation& );
