@@ -14,11 +14,11 @@
 
 #include "GPXElementDictionary.h"
 #include "GeoParser.h"
-#include "GeoDataDocument.h"
-#include "GeoDataPlacemark.h"
 #include "GeoDataPoint.h"
 #include "GeoDataTrack.h"
 
+#include <QDateTime>
+
 namespace Marble
 {
 namespace gpx
@@ -27,7 +27,7 @@ GPX_DEFINE_TAG_HANDLER(time)
 
 GeoNode* GPXtimeTagHandler::parse(GeoParser& parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(gpxTag_time));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(gpxTag_time)));
 
     GeoStackItem parentItem = parser.parentElement();
     if (parentItem.represents(gpxTag_trkpt))
