@@ -25,23 +25,23 @@ class JsonPlugin : public ParseRunnerPlugin
 public:
     explicit JsonPlugin( QObject *parent = 0 );
 
-    QString name() const;
+    QString name() const override;
 
-    QString nameId() const;
+    QString nameId() const override;
 
-    QString version() const;
+    QString version() const override;
 
-    QString description() const;
+    QString description() const override;
 
-    QString copyrightYears() const;
+    QString copyrightYears() const override;
 
     QVector<PluginAuthor> pluginAuthors() const override;
 
-    QString fileFormatDescription() const;
+    QString fileFormatDescription() const override;
 
-    QStringList fileExtensions() const;
+    QStringList fileExtensions() const override;
 
-    virtual ParsingRunner* newRunner() const;
+    ParsingRunner* newRunner() const override;
 };
 
 }
