@@ -26,21 +26,21 @@ class LocalDatabasePlugin : public SearchRunnerPlugin
 public:
     explicit LocalDatabasePlugin(QObject *parent = 0);
 
-    QString name() const;
+    QString name() const override;
 
-    QString guiString() const;
+    QString guiString() const override;
 
-    QString nameId() const;
+    QString nameId() const override;
 
-    QString version() const;
+    QString version() const override;
 
-    QString description() const;
+    QString description() const override;
 
-    QString copyrightYears() const;
+    QString copyrightYears() const override;
 
     QVector<PluginAuthor> pluginAuthors() const override;
 
-    virtual SearchRunner* newRunner() const;
+    SearchRunner* newRunner() const override;
 };
 
 }
