@@ -25,13 +25,13 @@ class MonavMapsModel : public QAbstractTableModel
 public:
     explicit MonavMapsModel( const QVector<MonavMap> &data, QObject * parent = 0 );
 
-    virtual QVariant headerData ( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
+    QVariant headerData ( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const override;
 
-    virtual QVariant data ( const QModelIndex & index, int role = Qt::DisplayRole ) const;
+    QVariant data ( const QModelIndex & index, int role = Qt::DisplayRole ) const override;
 
-    virtual int rowCount ( const QModelIndex & parent = QModelIndex() ) const;
+    int rowCount ( const QModelIndex & parent = QModelIndex() ) const override;
 
-    virtual int columnCount ( const QModelIndex & parent = QModelIndex() ) const;
+    int columnCount ( const QModelIndex & parent = QModelIndex() ) const override;
 
     static bool sortByName( const MonavMap &first, const MonavMap &second );
 
