@@ -37,9 +37,8 @@ class OpenRouteServiceRunner : public RoutingRunner
 public:
     explicit OpenRouteServiceRunner(QObject *parent = 0);
 
-    ~OpenRouteServiceRunner();
     // Overriding MarbleAbstractRunner
-    virtual void retrieveRoute( const RouteRequest *request );
+    void retrieveRoute( const RouteRequest *request ) override;
 
 private Q_SLOTS:
     /** Route data was retrieved via http */
@@ -51,20 +50,7 @@ private Q_SLOTS:
     void get();
 
 private:
-    /** Builds the xml request header. */
-    static QString xmlHeader();
-
-    /** Builds the route request header in the xml request. */
-    static QString requestHeader( const QString &unit, const QString &routePreference );
-
-    /** Builds a route point substring. */
-    static QString requestPoint( PointType pointType, const GeoDataCoordinates &coordinates );
-
-    /** Builds the route request footer in the xml request. */
-    static QString requestFooter( const QHash<QString, QVariant> &settings );
-
-    /** Builds the xml request footer. */
-    static QString xmlFooter();
+    static QString formatCoordinates(const GeoDataCoordinates &coordinates);
 
     GeoDataDocument* parse( const QByteArray &input ) const;
 
@@ -73,8 +59,6 @@ private:
     QNetworkAccessManager m_networkAccessManager;
 
     QNetworkRequest m_request;
-
-    QByteArray m_requestData;
 };
 
 }
