@@ -180,7 +180,7 @@ GeoDataDocument* OsmParser::parseXml(const QString &filename, QString &error)
                 m_relations[parentId].osmData() = OsmPlacemarkData::fromParserAttributes(parser.attributes());
                 osmData = &m_relations[parentId].osmData();
             }
-        } else if (tagName == osm::osmTag_tag) {
+        } else if (osmData && tagName == osm::osmTag_tag) {
             const QXmlStreamAttributes &attributes = parser.attributes();
             const QString keyString = *stringPool.insert(attributes.value(QLatin1String("k")).toString());
             const QString valueString = *stringPool.insert(attributes.value(QLatin1String("v")).toString());
@@ -213,25 +213,38 @@ GeoDataDocument *OsmParser::createDocument(OsmNodes &nodes, OsmWays &ways, OsmRe
     document->addStyle( backgroundStyle );
 
     QSet<qint64> usedNodes, usedWays;
-    foreach(OsmRelation const &relation, relations) {
-        relation.create(document, ways, nodes, usedNodes, usedWays);
+    for(auto const &relation: relations) {
+        relation.createMultipolygon(document, ways, nodes, usedNodes, usedWays);
     }
-    foreach(qint64 id, usedWays) {
+    for(auto id: usedWays) {
         ways.remove(id);
     }
 
-    foreach(OsmWay const &way, ways) {
-        way.create(document, nodes, usedNodes);
+    QHash<qint64, GeoDataPlacemark*> placemarks;
+    for (auto iter=ways.constBegin(), end=ways.constEnd(); iter != end; ++iter) {
+        auto placemark = iter.value().create(nodes, usedNodes);
+        if (placemark) {
+            document->append(placemark);
+            placemarks[placemark->osmData().oid()] = placemark;
+        }
     }
 
-    foreach(qint64 id, usedNodes) {
+    for(auto id: usedNodes) {
         if (nodes[id].osmData().isEmpty()) {
             nodes.remove(id);
         }
     }
 
-    foreach(OsmNode const &node, nodes) {
-        node.create(document);
+    for(auto const &node: nodes) {
+        auto placemark = node.create();
+        if (placemark) {
+            document->append(placemark);
+            placemarks[placemark->osmData().oid()] = placemark;
+        }
+    }
+
+    for(auto const &relation: relations) {
+        relation.createRelation(document, placemarks);
     }
 
     return document;
