@@ -10,8 +10,8 @@
 
 #include <QList>
 #include <QHash>
+#include <QSet>
 
-#include "GeoDataTypes.h"
 #include "GeoDataPlacemark.h"
 #include "GeoDataDocument.h"
 #include "GeoDataObject.h"
@@ -27,76 +27,82 @@
 namespace Marble {
 
 WayConcatenator::WayConcatenator(GeoDataDocument *document) :
-    BaseFilter(document),
     m_originalWays(0),
     m_mergedWays(0)
 {
     typedef QSharedPointer<GeoDataPlacemark> PlacemarkPtr;
-    foreach (GeoDataPlacemark* original, placemarks()) {
-        PlacemarkPtr placemark = PlacemarkPtr(new GeoDataPlacemark(*original));
-        OsmObjectManager::initializeOsmData(placemark.data());
-        bool isWay = false;
-        if (placemark->geometry()->nodeType() == GeoDataTypes::GeoDataLineStringType) {
-            OsmPlacemarkData const & osmData = placemark->osmData();
-            isWay = osmData.containsTagKey("highway") ||
-                    osmData.containsTagKey("railway") ||
-                    osmData.containsTagKey("waterway");
-            if (isWay) {
-                GeoDataLineString *line = static_cast<GeoDataLineString*>(placemark->geometry());
-                qint64 firstId = osmData.nodeReference(line->first()).oid();
-                qint64 lastId = osmData.nodeReference(line->last()).oid();
-                if (firstId > 0 && lastId > 0) {
-                    ++m_originalWays;
-                    bool containsFirst = m_hash.contains(firstId);
-                    bool containsLast = m_hash.contains(lastId);
+    for (GeoDataFeature *feature: document->featureList()) {
+        if (const auto original = geodata_cast<GeoDataPlacemark>(feature)) {
+            bool isWay = false;
+            if (geodata_cast<GeoDataLineString>(original->geometry())) {
+                PlacemarkPtr placemark = PlacemarkPtr(new GeoDataPlacemark(*original));
+                OsmObjectManager::initializeOsmData(placemark.data());
+                OsmPlacemarkData const & osmData = placemark->osmData();
+                isWay = osmData.containsTagKey("highway") ||
+                        osmData.containsTagKey("railway") ||
+                        osmData.containsTagKey("waterway");
+                if (isWay) {
+                    GeoDataLineString *line = static_cast<GeoDataLineString*>(placemark->geometry());
+                    qint64 firstId = osmData.nodeReference(line->first()).oid();
+                    qint64 lastId = osmData.nodeReference(line->last()).oid();
+                    if (firstId > 0 && lastId > 0) {
+                        ++m_originalWays;
+                        bool containsFirst = m_hash.contains(firstId);
+                        bool containsLast = m_hash.contains(lastId);
 
-                    if (!containsFirst && !containsLast) {
-                        createWayChunk(placemark, firstId, lastId);
-                    } else if (containsFirst && !containsLast) {
-                        auto chunk = wayChunk(*placemark, firstId);
-                        if (chunk != nullptr) {
-                            concatFirst(placemark, chunk);
-                        } else {
+                        if (!containsFirst && !containsLast) {
                             createWayChunk(placemark, firstId, lastId);
-                        }
-                    } else if (!containsFirst && containsLast) {
-                        auto chunk = wayChunk(*placemark, lastId);
-                        if (chunk != nullptr) {
-                            concatLast(placemark, chunk);
-                        } else {
-                            createWayChunk(placemark, firstId, lastId);
-                        }
-                    } else if (containsFirst && containsLast) {
-                        auto chunk = wayChunk(*placemark, firstId);
-                        auto otherChunk = wayChunk(*placemark, lastId);
-
-                        if (chunk != nullptr && otherChunk != nullptr) {
-                            if(chunk == otherChunk) {
-                                m_wayPlacemarks.append(placemark);
+                        } else if (containsFirst && !containsLast) {
+                            auto chunk = wayChunk(*placemark, firstId);
+                            if (chunk != nullptr) {
+                                concatFirst(placemark, chunk);
                             } else {
-                                concatBoth(placemark, chunk, otherChunk);
+                                createWayChunk(placemark, firstId, lastId);
+                            }
+                        } else if (!containsFirst && containsLast) {
+                            auto chunk = wayChunk(*placemark, lastId);
+                            if (chunk != nullptr) {
+                                concatLast(placemark, chunk);
+                            } else {
+                                createWayChunk(placemark, firstId, lastId);
+                            }
+                        } else if (containsFirst && containsLast) {
+                            auto chunk = wayChunk(*placemark, firstId);
+                            auto otherChunk = wayChunk(*placemark, lastId);
+
+                            if (chunk != nullptr && otherChunk != nullptr) {
+                                if(chunk == otherChunk) {
+                                    m_wayPlacemarks.append(placemark);
+                                } else {
+                                    concatBoth(placemark, chunk, otherChunk);
+                                }
+                            } else if(chunk != nullptr && otherChunk == nullptr) {
+                                concatFirst(placemark, chunk);
+                            } else if(chunk == nullptr && otherChunk != nullptr) {
+                                concatLast(placemark, otherChunk);
+                            } else {
+                                createWayChunk(placemark, firstId, lastId);
                             }
-                        } else if(chunk != nullptr && otherChunk == nullptr) {
-                            concatFirst(placemark, chunk);
-                        } else if(chunk == nullptr && otherChunk != nullptr) {
-                            concatLast(placemark, otherChunk);
-                        } else {
-                            createWayChunk(placemark, firstId, lastId);
                         }
+                    } else {
+                        isWay = false;
                     }
-                } else {
-                    isWay = false;
                 }
             }
-        }
 
-        if (!isWay) {
-            m_otherPlacemarks << new GeoDataPlacemark(*original);
+            if (!isWay) {
+                m_otherPlacemarks << feature->clone();
+            }
+        } else {
+            m_otherPlacemarks << feature->clone();
         }
     }
 
-    prepareDocument();
-    addWayChunks();
+    document->clear();
+    for (auto placemark: m_otherPlacemarks) {
+        document->append(placemark);
+    }
+    addWayChunks(document);
 }
 
 int WayConcatenator::originalWays() const
@@ -109,10 +115,10 @@ int WayConcatenator::mergedWays() const
     return m_mergedWays;
 }
 
-void WayConcatenator::addWayChunks()
+void WayConcatenator::addWayChunks(GeoDataDocument *document)
 {
     for (auto const &placemark: m_wayPlacemarks) {
-        document()->append(new GeoDataPlacemark(*placemark));
+        document->append(placemark->clone());
     }
 
     QSet<WayChunk::Ptr> chunkSet;
@@ -123,7 +129,7 @@ void WayConcatenator::addWayChunks()
             chunkSet.insert(*itr);
             PlacemarkPtr placemark = (*itr)->merge();
             if (placemark) {
-                document()->append(new GeoDataPlacemark(*placemark));
+                document->append(placemark->clone());
             }
         }
     }
@@ -131,14 +137,6 @@ void WayConcatenator::addWayChunks()
     m_chunks.clear();
 }
 
-void WayConcatenator::prepareDocument()
-{
-    document()->clear();
-    for (auto placemark: m_otherPlacemarks) {
-        document()->append(placemark);
-    }
-}
-
 void WayConcatenator::createWayChunk(const PlacemarkPtr &placemark, qint64 firstId, qint64 lastId)
 {
     WayChunk::Ptr chunk = WayChunk::Ptr(new WayChunk(placemark, firstId, lastId));
@@ -153,7 +151,7 @@ WayChunk::Ptr WayConcatenator::wayChunk(const GeoDataPlacemark &placemark, qint6
 {
     QHash<qint64, WayChunk::Ptr>::ConstIterator matchItr = m_hash.find(matchId);
     while (matchItr != m_hash.end() && matchItr.key() == matchId) {
-        auto chunk = matchItr.value();
+        auto const & chunk = matchItr.value();
         if (chunk->concatPossible(placemark)) {
             return chunk;
         }
